Description Usage Format Value Examples
The example data set has the same structure as the banks' data and can be used to explore the plotting possibilities.
1 |
An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 1170 rows and 8 columns.
A dataframe.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.